@@ -8,8 +8,8 @@ CODEGEN_PKG=${CODEGEN_PKG:-$(cd ${SCRIPT_ROOT}; ls -d -1 ./vendor/k8s.io/code-ge
 verify="${VERIFY:-}"
 
 GOFLAGS="" bash ${CODEGEN_PKG}/generate-groups.sh "deepcopy" \
-  github.com/open-cluster-management/submariner-addon/generated \
-  github.com/open-cluster-management/submariner-addon/pkg/apis \
+  github.com/stolostron/submariner-addon/generated \
+  github.com/stolostron/submariner-addon/pkg/apis \
   "submarinerconfig:v1alpha1" \
   --go-header-file ${SCRIPT_ROOT}/hack/empty.txt \
   ${verify}
